==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/ListGroupAssignedRoles200ResponseInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CustomRole;
import com.okta.sdk.resource.model.LifecycleStatus;
import com.okta.sdk.resource.model.LinksCustomRoleResponse;
import com.okta.sdk.resource.model.RoleAssignmentType;
import com.okta.sdk.resource.model.RoleType;
import com.okta.sdk.resource.model.StandardRole;
import com.okta.sdk.resource.model.StandardRoleEmbedded;
import java.time.OffsetDateTime;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ListGroupAssignedRoles200ResponseInner
 */
@JsonPropertyOrder({ ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_ASSIGNMENT_TYPE,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_CREATED,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_ID,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_LABEL,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_LAST_UPDATED,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_STATUS,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_TYPE,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_EMBEDDED,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_LINKS,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_RESOURCE_SET,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_ROLE })
@JsonTypeName("listGroupAssignedRoles_200_response_inner")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ListGroupAssignedRoles200ResponseInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ASSIGNMENT_TYPE = "assignmentType";
    private RoleAssignmentType assignmentType;

    public static final String JSON_PROPERTY_CREATED = "created";
    private OffsetDateTime created;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_LABEL = "label";
    private String label;

    public static final String JSON_PROPERTY_LAST_UPDATED = "lastUpdated";
    private OffsetDateTime lastUpdated;

    public static final String JSON_PROPERTY_STATUS = "status";
    private LifecycleStatus status;

    public static final String JSON_PROPERTY_TYPE = "type";
    private RoleType type;

    public static final String JSON_PROPERTY_EMBEDDED = "_embedded";
    private StandardRoleEmbedded embedded;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private LinksCustomRoleResponse links;

    public static final String JSON_PROPERTY_RESOURCE_SET = "resource-set";
    private String resourceSet;

    public static final String JSON_PROPERTY_ROLE = "role";
    private String role;

    public ListGroupAssignedRoles200ResponseInner() {
    }

    /*
     * @JsonCreator public ListGroupAssignedRoles200ResponseInner(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED) OffsetDateTime created,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LABEL) String label,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED) OffsetDateTime lastUpdated,
     *
     * @JsonProperty(JSON_PROPERTY_RESOURCE_SET) String resourceSet,
     *
     * @JsonProperty(JSON_PROPERTY_ROLE) String role ) { this(); this.created = created; this.id = id; this.label =
     * label; this.lastUpdated = lastUpdated; this.resourceSet = resourceSet; this.role = role; }
     */

    public ListGroupAssignedRoles200ResponseInner assignmentType(RoleAssignmentType assignmentType) {

        this.assignmentType = assignmentType;
        return this;
    }

    /**
     * Get assignmentType
     *
     * @return assignmentType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ASSIGNMENT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public RoleAssignmentType getAssignmentType() {
        return assignmentType;
    }

    @JsonProperty(JSON_PROPERTY_ASSIGNMENT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAssignmentType(RoleAssignmentType assignmentType) {
        this.assignmentType = assignmentType;
    }

    /**
     * Timestamp when the object was created
     *
     * @return created
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Timestamp when the object was created")
    @JsonProperty(JSON_PROPERTY_CREATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OffsetDateTime getCreated() {
        return created;
    }

    /**
     * Binding Object ID
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Binding Object ID")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    /**
     * Label for the custom role assignment
     *
     * @return label
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Label for the custom role assignment")
    @JsonProperty(JSON_PROPERTY_LABEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getLabel() {
        return label;
    }

    /**
     * Timestamp when the object was last updated
     *
     * @return lastUpdated
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Timestamp when the object was last updated")
    @JsonProperty(JSON_PROPERTY_LAST_UPDATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OffsetDateTime getLastUpdated() {
        return lastUpdated;
    }

    public ListGroupAssignedRoles200ResponseInner status(LifecycleStatus status) {

        this.status = status;
        return this;
    }

    /**
     * Get status
     *
     * @return status
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LifecycleStatus getStatus() {
        return status;
    }

    @JsonProperty(JSON_PROPERTY_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setStatus(LifecycleStatus status) {
        this.status = status;
    }

    public ListGroupAssignedRoles200ResponseInner type(RoleType type) {

        this.type = type;
        return this;
    }

    /**
     * Get type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public RoleType getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(RoleType type) {
        this.type = type;
    }

    public ListGroupAssignedRoles200ResponseInner embedded(StandardRoleEmbedded embedded) {

        this.embedded = embedded;
        return this;
    }

    /**
     * Get embedded
     *
     * @return embedded
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EMBEDDED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public StandardRoleEmbedded getEmbedded() {
        return embedded;
    }

    @JsonProperty(JSON_PROPERTY_EMBEDDED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEmbedded(StandardRoleEmbedded embedded) {
        this.embedded = embedded;
    }

    public ListGroupAssignedRoles200ResponseInner links(LinksCustomRoleResponse links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksCustomRoleResponse getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(LinksCustomRoleResponse links) {
        this.links = links;
    }

    /**
     * Resource Set ID
     *
     * @return resourceSet
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Resource Set ID")
    @JsonProperty(JSON_PROPERTY_RESOURCE_SET)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getResourceSet() {
        return resourceSet;
    }

    /**
     * Custom Role ID
     *
     * @return role
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Custom Role ID")
    @JsonProperty(JSON_PROPERTY_ROLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getRole() {
        return role;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ListGroupAssignedRoles200ResponseInner listGroupAssignedRoles200ResponseInner = (ListGroupAssignedRoles200ResponseInner) o;
        return Objects.equals(this.assignmentType, listGroupAssignedRoles200ResponseInner.assignmentType)
                && Objects.equals(this.created, listGroupAssignedRoles200ResponseInner.created)
                && Objects.equals(this.id, listGroupAssignedRoles200ResponseInner.id)
                && Objects.equals(this.label, listGroupAssignedRoles200ResponseInner.label)
                && Objects.equals(this.lastUpdated, listGroupAssignedRoles200ResponseInner.lastUpdated)
                && Objects.equals(this.status, listGroupAssignedRoles200ResponseInner.status)
                && Objects.equals(this.type, listGroupAssignedRoles200ResponseInner.type)
                && Objects.equals(this.embedded, listGroupAssignedRoles200ResponseInner.embedded)
                && Objects.equals(this.links, listGroupAssignedRoles200ResponseInner.links)
                && Objects.equals(this.resourceSet, listGroupAssignedRoles200ResponseInner.resourceSet)
                && Objects.equals(this.role, listGroupAssignedRoles200ResponseInner.role);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(assignmentType, created, id, label, lastUpdated, status, type, embedded, links, resourceSet,
                role);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ListGroupAssignedRoles200ResponseInner {\n");
        sb.append("    assignmentType: ").append(toIndentedString(assignmentType)).append("\n");
        sb.append("    created: ").append(toIndentedString(created)).append("\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    label: ").append(toIndentedString(label)).append("\n");
        sb.append("    lastUpdated: ").append(toIndentedString(lastUpdated)).append("\n");
        sb.append("    status: ").append(toIndentedString(status)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    embedded: ").append(toIndentedString(embedded)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("    resourceSet: ").append(toIndentedString(resourceSet)).append("\n");
        sb.append("    role: ").append(toIndentedString(role)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/ListGroupAssignedRoles200ResponseInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CustomRole;
import com.okta.sdk.resource.model.LifecycleStatus;
import com.okta.sdk.resource.model.LinksCustomRoleResponse;
import com.okta.sdk.resource.model.RoleAssignmentType;
import com.okta.sdk.resource.model.RoleType;
import com.okta.sdk.resource.model.StandardRole;
import com.okta.sdk.resource.model.StandardRoleEmbedded;
import java.time.OffsetDateTime;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ListGroupAssignedRoles200ResponseInner
 */
@JsonPropertyOrder({ ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_ASSIGNMENT_TYPE,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_CREATED,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_ID,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_LABEL,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_LAST_UPDATED,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_STATUS,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_TYPE,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_EMBEDDED,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_LINKS,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_RESOURCE_SET,
        ListGroupAssignedRoles200ResponseInner.JSON_PROPERTY_ROLE })
@JsonTypeName("listGroupAssignedRoles_200_response_inner")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class ListGroupAssignedRoles200ResponseInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ASSIGNMENT_TYPE = "assignmentType";
    private RoleAssignmentType assignmentType;

    public static final String JSON_PROPERTY_CREATED = "created";
    private OffsetDateTime created;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_LABEL = "label";
    private String label;

    public static final String JSON_PROPERTY_LAST_UPDATED = "lastUpdated";
    private OffsetDateTime lastUpdated;

    public static final String JSON_PROPERTY_STATUS = "status";
    private LifecycleStatus status;

    public static final String JSON_PROPERTY_TYPE = "type";
    private RoleType type;

    public static final String JSON_PROPERTY_EMBEDDED = "_embedded";
    private StandardRoleEmbedded embedded;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private LinksCustomRoleResponse links;

    public static final String JSON_PROPERTY_RESOURCE_SET = "resource-set";
    private String resourceSet;

    public static final String JSON_PROPERTY_ROLE = "role";
    private String role;

    public ListGroupAssignedRoles200ResponseInner() {
    }

    /*
     * @JsonCreator public ListGroupAssignedRoles200ResponseInner(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED) OffsetDateTime created,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LABEL) String label,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED) OffsetDateTime lastUpdated,
     *
     * @JsonProperty(JSON_PROPERTY_RESOURCE_SET) String resourceSet,
     *
     * @JsonProperty(JSON_PROPERTY_ROLE) String role ) { this(); this.created = created; this.id = id; this.label =
     * label; this.lastUpdated = lastUpdated; this.resourceSet = resourceSet; this.role = role; }
     */

    public ListGroupAssignedRoles200ResponseInner assignmentType(RoleAssignmentType assignmentType) {

        this.assignmentType = assignmentType;
        return this;
    }

    /**
     * Get assignmentType
     *
     * @return assignmentType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ASSIGNMENT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public RoleAssignmentType getAssignmentType() {
        return assignmentType;
    }

    @JsonProperty(JSON_PROPERTY_ASSIGNMENT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAssignmentType(RoleAssignmentType assignmentType) {
        this.assignmentType = assignmentType;
    }

    /**
     * Timestamp when the object was created
     *
     * @return created
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Timestamp when the object was created")
    @JsonProperty(JSON_PROPERTY_CREATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OffsetDateTime getCreated() {
        return created;
    }

    /**
     * Binding Object ID
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Binding Object ID")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    /**
     * Label for the custom role assignment
     *
     * @return label
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Label for the custom role assignment")
    @JsonProperty(JSON_PROPERTY_LABEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getLabel() {
        return label;
    }

    /**
     * Timestamp when the object was last updated
     *
     * @return lastUpdated
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Timestamp when the object was last updated")
    @JsonProperty(JSON_PROPERTY_LAST_UPDATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OffsetDateTime getLastUpdated() {
        return lastUpdated;
    }

    public ListGroupAssignedRoles200ResponseInner status(LifecycleStatus status) {

        this.status = status;
        return this;
    }

    /**
     * Get status
     *
     * @return status
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LifecycleStatus getStatus() {
        return status;
    }

    @JsonProperty(JSON_PROPERTY_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setStatus(LifecycleStatus status) {
        this.status = status;
    }

    public ListGroupAssignedRoles200ResponseInner type(RoleType type) {

        this.type = type;
        return this;
    }

    /**
     * Get type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public RoleType getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(RoleType type) {
        this.type = type;
    }

    public ListGroupAssignedRoles200ResponseInner embedded(StandardRoleEmbedded embedded) {

        this.embedded = embedded;
        return this;
    }

    /**
     * Get embedded
     *
     * @return embedded
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EMBEDDED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public StandardRoleEmbedded getEmbedded() {
        return embedded;
    }

    @JsonProperty(JSON_PROPERTY_EMBEDDED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEmbedded(StandardRoleEmbedded embedded) {
        this.embedded = embedded;
    }

    public ListGroupAssignedRoles200ResponseInner links(LinksCustomRoleResponse links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksCustomRoleResponse getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(LinksCustomRoleResponse links) {
        this.links = links;
    }

    /**
     * Resource Set ID
     *
     * @return resourceSet
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Resource Set ID")
    @JsonProperty(JSON_PROPERTY_RESOURCE_SET)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getResourceSet() {
        return resourceSet;
    }

    /**
     * Custom Role ID
     *
     * @return role
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Custom Role ID")
    @JsonProperty(JSON_PROPERTY_ROLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getRole() {
        return role;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ListGroupAssignedRoles200ResponseInner listGroupAssignedRoles200ResponseInner = (ListGroupAssignedRoles200ResponseInner) o;
        return Objects.equals(this.assignmentType, listGroupAssignedRoles200ResponseInner.assignmentType)
                && Objects.equals(this.created, listGroupAssignedRoles200ResponseInner.created)
                && Objects.equals(this.id, listGroupAssignedRoles200ResponseInner.id)
                && Objects.equals(this.label, listGroupAssignedRoles200ResponseInner.label)
                && Objects.equals(this.lastUpdated, listGroupAssignedRoles200ResponseInner.lastUpdated)
                && Objects.equals(this.status, listGroupAssignedRoles200ResponseInner.status)
                && Objects.equals(this.type, listGroupAssignedRoles200ResponseInner.type)
                && Objects.equals(this.embedded, listGroupAssignedRoles200ResponseInner.embedded)
                && Objects.equals(this.links, listGroupAssignedRoles200ResponseInner.links)
                && Objects.equals(this.resourceSet, listGroupAssignedRoles200ResponseInner.resourceSet)
                && Objects.equals(this.role, listGroupAssignedRoles200ResponseInner.role);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(assignmentType, created, id, label, lastUpdated, status, type, embedded, links, resourceSet,
                role);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ListGroupAssignedRoles200ResponseInner {\n");
        sb.append("    assignmentType: ").append(toIndentedString(assignmentType)).append("\n");
        sb.append("    created: ").append(toIndentedString(created)).append("\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    label: ").append(toIndentedString(label)).append("\n");
        sb.append("    lastUpdated: ").append(toIndentedString(lastUpdated)).append("\n");
        sb.append("    status: ").append(toIndentedString(status)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    embedded: ").append(toIndentedString(embedded)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("    resourceSet: ").append(toIndentedString(resourceSet)).append("\n");
        sb.append("    role: ").append(toIndentedString(role)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
